@@ -1,22 +1,22 @@
-// ************************************************************************* 
-// Copyright (c) 2014-2016, SUSE LLC
-// 
+// *************************************************************************
+// Copyright (c) 2014-2017, SUSE LLC
+//
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 // 1. Redistributions of source code must retain the above copyright notice,
 // this list of conditions and the following disclaimer.
-// 
+//
 // 2. Redistributions in binary form must reproduce the above copyright
 // notice, this list of conditions and the following disclaimer in the
 // documentation and/or other materials provided with the distribution.
-// 
+//
 // 3. Neither the name of SUSE LLC nor the names of its contributors may be
 // used to endorse or promote products derived from this software without
 // specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 // AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 // IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -28,7 +28,7 @@
 // CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
-// ************************************************************************* 
+// *************************************************************************
 //
 // app/drowselect-init.js
 //
@@ -37,49 +37,42 @@
 "use strict";
 
 define ([
-    'lib',
     'app/lib',
     'target'
 ], function (
-    lib,
-    dochazkaLib,
+    appLib,
     target
 ) {
 
-    var entries = dochazkaLib.entries;
+    var entries = appLib.entries;
 
     return function () {
 
         target.push('privHistoryDrowselect', {
             'name': 'privHistoryDrowselect',
             'type': 'drowselect',
-            'menuText': 'Privilege (status) history',
-            'title': 'Privilege (status) history',
+            'menuText': 'Privilege (status) history - edit',
+            'title': 'Privilege (status) history - edit',
             'preamble': null,
             'aclProfile': 'admin',
-            'entries': [entries.pHeffective, entries.pHpriv],
-            'hook': lib.holdObject,
+            'entries': [entries.ePnick, entries.pHeffective, entries.pHpriv],
             'miniMenu': {
-                entries: ['privHistoryAddRecord', 'privHistoryDeleteAction'],
-                back: ['Back', 'actionPrivHistory']
+                entries: ['privHistoryAddRecordAction', 'privHistoryDeleteAction']
             }
         });
 
         target.push('schedHistoryDrowselect', {
             'name': 'schedHistoryDrowselect',
             'type': 'drowselect',
-            'menuText': 'Schedule history',
-            'title': 'Schedule history',
+            'menuText': 'Schedule history - edit',
+            'title': 'Schedule history - edit',
             'preamble': null,
             'aclProfile': 'admin',
             'entries': [entries.pHeffective, entries.sDid, entries.sDcode],
-            'hook': lib.holdObject,
             'miniMenu': {
-                entries: ['schedHistoryAddRecord', 'schedHistoryDeleteAction'],
-                back: ['Back', 'actionSchedHistory']
+                entries: ['schedHistoryAddRecordAction', 'schedHistoryDeleteAction'],
             }
         });
 
     };
-    
 });
