@@ -1,22 +1,22 @@
-// ************************************************************************* 
-// Copyright (c) 2014-2016, SUSE LLC
-// 
+// *************************************************************************
+// Copyright (c) 2014-2017, SUSE LLC
+//
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 // 1. Redistributions of source code must retain the above copyright notice,
 // this list of conditions and the following disclaimer.
-// 
+//
 // 2. Redistributions in binary form must reproduce the above copyright
 // notice, this list of conditions and the following disclaimer in the
 // documentation and/or other materials provided with the distribution.
-// 
+//
 // 3. Neither the name of SUSE LLC nor the names of its contributors may be
 // used to endorse or promote products derived from this software without
 // specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 // AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 // IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -28,7 +28,7 @@
 // CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
-// ************************************************************************* 
+// *************************************************************************
 //
 // app/emp-lib.js
 //
@@ -41,6 +41,7 @@ define ([
     'lib',
     'app/lib',
     'app/prototypes',
+    'stack',
     'start',
     'target'
 ], function (
@@ -50,37 +51,46 @@ define ([
     coreLib,
     appLib,
     prototypes,
+    stack,
     start,
     target
 ) {
 
     var 
-        employeeObject = Object.create(prototypes.empObject),
-        employeeProfile = Object.create(prototypes.empProfile),
         ldapEmployeeObject = Object.create(prototypes.ldapEmpObject),
 
-        getEmployeeObject = function () { return employeeObject; },
-        getEmployeeProfile = function () { return employeeProfile; },
         getLdapEmployeeObject = function () { return ldapEmployeeObject; },
 
-        myProfile = function () {
-            loadEmpProfile(currentUser('obj').eid);
-        },
-
-        loadEmpProfile = function (eid) {
-            var rest = {
+        myProfileAction = function () {
+            var eid = currentUser('obj').eid,
+                rest = {
                     "method": 'GET',
                     "path": 'employee/eid/' + eid + '/full'
                 },
+                employeeProfile,
                 // success callback
                 sc = function (st) {
                     if (st.code === 'DISPATCH_EMPLOYEE_PROFILE_FULL') {
                         console.log("Payload is", st.payload);
                         var priv = null,
-                            effective = null;
+                            privEffective = null,
+                            sched = null,
+                            schedEffective = null;
                         if (st.payload.privhistory !== null) {
                             priv = st.payload.privhistory.priv;
-                            effective = coreLib.readableDate(st.payload.privhistory.effective);
+                            privEffective = coreLib.readableDate(
+                                st.payload.privhistory.effective
+                            );
+                        }
+                        if (st.payload.schedhistory !== null) {
+                            if (st.payload.schedhistory.scode !== null) {
+                                sched = st.payload.schedhistory.scode;
+                            } else {
+                                sched = '(Schedule ID ' + st.payload.schedhistory.sid + ')';
+                            }
+                            schedEffective = coreLib.readableDate(
+                                st.payload.schedhistory.effective
+                            );
                         }
                         employeeProfile = $.extend(
                             Object.create(prototypes.empProfile), {
@@ -91,11 +101,15 @@ define ([
                                 'remark': st.payload.emp.remark,
                                 'sec_id': st.payload.emp.sec_id,
                                 'priv': priv,
-                                'effective': effective
+                                'privEffective': privEffective,
+                                'sched': sched,
+                                'schedEffective': schedEffective
                             }
                         );
                         currentUser('obj', employeeProfile);
-                        target.pull('empProfile').start();
+                        stack.push('empProfile', employeeProfile, {
+                            "xtarget": "mainEmpl"
+                        });
                     } else {
                         coreLib.displayError("Unexpected status code " + st.code);
                     }
@@ -109,6 +123,9 @@ define ([
 
         actionEmplSearch = function (obj) {
             // obj is searchKeyNick from the form
+            if (! obj) {
+                obj = stack.getState();
+            }
             console.log("Entering target 'actionEmplSearch' with argument", obj);
             var rest = {
                     "method": 'GET',
@@ -124,9 +141,10 @@ define ([
                             count = rs.length;
         
                         console.log("Search found " + count + " employees");
-                        coreLib.holdObject(rs);
-                        target.pull('simpleEmployeeBrowser').start();
-
+                        stack.push('simpleEmployeeBrowser', {
+                            'set': rs,
+                            'pos': 0
+                        });
                     } else {
                         coreLib.displayError("Unexpected status code " + st.code);
                     }
@@ -137,6 +155,7 @@ define ([
                     coreLib.displayError(st.payload.message);
                 };
             ajax(rest, sc, fc);
+            coreLib.ajaxMessage();
         },
 
         // masquerade as a different employee
@@ -154,6 +173,7 @@ define ([
             $('input[name="sel"]').val('');
         },
         masqEmp = function (obj) {
+            console.log("Entering masqEmp with object", obj);
             // if obj is empty, dA was selected from menu
             // if obj is full, it contains the employee to masquerade as
         
@@ -164,12 +184,11 @@ define ([
 
             var cu = currentUser('obj');
 
-            if (obj && obj.nick === cu.nick) {
-                $('#result').html('Request to masquerade as self makes no sense');
-                return;
-            }
-
-            if (obj) {
+            if (! coreLib.isObjEmpty(obj)) {
+                if (obj.nick === cu.nick) {
+                    $('#result').html('Request to masquerade as self makes no sense');
+                    return;
+                }
                 // let the masquerade begin
                 currentEmployeeStashed = $.extend({}, cu);
                 backgroundColorStashed = $('#mainarea').css("background-color");
@@ -177,16 +196,19 @@ define ([
                 currentUser('flag1', 1); // turn on masquerade flag
                 $('#userbox').html(appLib.fillUserBox()); // reset userbox
                 $('#mainarea').css("background-color", "red");
-                target.pull('mainEmpl').start();
+                stack.unwindToFlag(); // return to most recent dmenu
                 return;
             }
         
             // let the admin pick which user to masquerade as
-            target.pull('searchEmployee').start();
+            stack.push('searchEmployee', {}, {
+                "xtarget": "mainEmpl"
+            });
         },
 
-        ldapLookupSubmit = function (emp) {
-            console.log("Entering function ldapLookupSubmit, argument ->" + emp.nick + "<-");
+        ldapLookupSubmit = function () {
+            var emp = stack.getState();
+            console.log("Entering function ldapLookupSubmit, object", emp);
             // "nick" is the only property of emp that is populated
             if (! emp.nick) {
                 return;
@@ -200,7 +222,7 @@ define ([
                 sc = function (st) {
                     if (st.code === 'DOCHAZKA_LDAP_LOOKUP') {
                         console.log("Payload is", st.payload);
-                        ldapEmployeeObject = $.extend(ldapEmployeeObject, st.payload);
+                        $.extend(ldapEmployeeObject, st.payload);
                     }
                     ldapEmployeeLink();
                 },
@@ -210,6 +232,7 @@ define ([
                     coreLib.displayError(st.payload.message);
                 };
             ajax(rest, sc, fc);
+            coreLib.ajaxMessage();
         },
 
         ldapEmployeeLink = function () {
@@ -232,27 +255,34 @@ define ([
                     }
                     if (document.getElementById('ldapLookup') ||
                         document.getElementById('ldapDisplayEmployee')) {
-                        target.pull('ldapDisplayEmployee').start();
+                        target.pull('ldapDisplayEmployee').start(ldapEmployeeObject);
                     }
                 },
                 fc = function (st) {
                     if (document.getElementById('ldapLookup') ||
                         document.getElementById('ldapDisplayEmployee')) {
-                        target.pull('ldapDisplayEmployee').start();
+                        target.pull('ldapDisplayEmployee').start(ldapEmployeeObject);
                     }
                 }
             ajax(rest, sc, fc);
         },
 
+        ldapSyncFromBrowser = function (obj) {
+            ldapSync(obj);
+        },
+
         ldapSync = function (ldapEmp) {
+            if (! ldapEmp) {
+                stack.getState();
+            }
             console.log("Entered ldapSync with object", ldapEmp);
             if (! ldapEmp.nick) {
                 return;
             }
-            ldapEmployeeObject = $.extend(
-                Object.create(prototypes.ldapEmpObject),
-                ldapEmp
-            );
+            // ldapEmployeeObject = $.extend(
+            //     Object.create(prototypes.ldapEmpObject),
+            //     ldapEmp
+            // );
             var nick = ldapEmp.nick,
                 rest = {
                     method: 'PUT',
@@ -267,17 +297,21 @@ define ([
                         ldapEmployeeObject.dochazka = true;
                     }
                     if (document.getElementById('ldapDisplayEmployee')) {
+                        console.log("ldapDisplayEmployee DOM element is present");
                         ldapEmployeeLink();
                     }
                     if (document.getElementById('simpleEmployeeBrowser')) {
+                        console.log("simpleEmployeeBrowser DOM element is present");
+                        // FIXME: this code belongs in App::MFILE::WWW
                         var obj = coreLib.dbrowserState.set[coreLib.dbrowserState.pos];
                         $.extend(coreLib.dbrowserState.obj, ldapEmployeeObject);
                         $.extend(obj, ldapEmployeeObject);
                         start.dbrowserListen();
                     }
                     if (document.getElementById('empProfile')) {
-                        console.log("ldapSyncSelf AJAX success!");
-                        myProfile();
+                        console.log("empProfile DOM element is present");
+                        $("#result").html("Employee profile updated from LDAP");
+                        stack.unwindToFlag(); // return to most recent dmenu
                     }
                 },
                 // failure callback -- employee doesn't exist
@@ -293,37 +327,28 @@ define ([
                     coreLib.displayError(msg);
                 }
             ajax(rest, sc, fc);
+            coreLib.ajaxMessage();
         },
 
-        ldapSyncSelf = function (ldapEmp) {
-            return ldapSync(ldapEmp);
-        },
-
-	// epuGen ("generate employee profile update function") is called to
-	// save changes to the database
-        //
-	// the argument afterTarget is the name of the target to go to
-	// when the database update is finished
-        //
-        epuGen = function (afterTarget, emp) {
-            var protoEmp = Object.create(prototypes.empProfile);
-            console.log("Entering epuGen with target " + afterTarget + " and object", emp);
+        empProfileEditSave = function (emp) {
+            var protoEmp = Object.create(prototypes.empProfile),
+                employeeProfile;
+            console.log("Entering empProfileEditSave with object", emp);
             $.extend(protoEmp, emp);
             var rest = {
                     "method": 'POST',
-                    "path": 'employee/eid',
+                    "path": 'employee/nick',
                     "body": protoEmp.sanitize()
                 },
                 sc = function (st) {
                     // st stands for "status", i.e. AJAX return value/object
-                    if (afterTarget === 'empProfile') {
-                        // this is an employee profile update
-                        $("#result").html("Employee profile updated");
-                    }
                     console.log("Saved new employee object to database: ", protoEmp);
+                    employeeProfile = Object.create(prototypes.empProfile);
                     $.extend(employeeProfile, st.payload);
                     console.log("Profile object is", employeeProfile);
-                    target.pull(afterTarget).start();
+                    currentUser('obj', employeeProfile);
+                    stack.unwindToFlag(); // return to most recent dmenu
+                    $("#result").html("Employee profile updated");
                 },
                 fc = function (st) {
                     console.log("AJAX: " + rest["path"] + " failed with", st);
@@ -335,16 +360,12 @@ define ([
     // here is where we define methods implementing the various
     // employee-related actions (see daction-start.js)
     return {
-        getEmployeeObject: getEmployeeObject,
-        getEmployeeProfile: getEmployeeProfile,
         getLdapEmployeeObject: getLdapEmployeeObject,
-        // mainEmpl: function (emp) { epuGen('mainEmpl', emp); },
-        myProfile: myProfile,
-        loadEmpProfile: loadEmpProfile,
-        empProfileEditSave: function (emp) { epuGen('empProfile', emp); },
+        myProfileAction: myProfileAction,
+        empProfileEditSave: empProfileEditSave,
         ldapLookupSubmit: ldapLookupSubmit,
         ldapSync: ldapSync,
-        ldapSyncSelf: ldapSyncSelf,
+        ldapSyncFromBrowser: ldapSyncFromBrowser,
         actionEmplSearch: actionEmplSearch,
         endTheMasquerade: endTheMasquerade,
         masqEmployee: masqEmp
