@@ -1,22 +1,22 @@
-// ************************************************************************* 
-// Copyright (c) 2014-2016, SUSE LLC
-// 
+// *************************************************************************
+// Copyright (c) 2014-2017, SUSE LLC
+//
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 // 1. Redistributions of source code must retain the above copyright notice,
 // this list of conditions and the following disclaimer.
-// 
+//
 // 2. Redistributions in binary form must reproduce the above copyright
 // notice, this list of conditions and the following disclaimer in the
 // documentation and/or other materials provided with the distribution.
-// 
+//
 // 3. Neither the name of SUSE LLC nor the names of its contributors may be
 // used to endorse or promote products derived from this software without
 // specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 // AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 // IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -28,7 +28,7 @@
 // CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
-// ************************************************************************* 
+// *************************************************************************
 //
 // app/priv-lib.js
 //
@@ -40,6 +40,7 @@ define ([
     'lib',
     'current-user',
     'target',
+    'stack',
     'start'
 ], function (
     $,
@@ -47,14 +48,17 @@ define ([
     lib,
     currentUser,
     target,
+    stack,
     start
 ) {
 
     var genPrivHistoryAction = function (tgt) {
-            return function () {
-                var rest = {
+            return function (obj) {
+                console.log("Entering some privHistory-related function, target is " + tgt);
+                var nick = currentUser('obj').nick,
+                    rest = {
                         "method": 'GET',
-                        "path": 'priv/history/nick/' + currentUser('obj').nick
+                        "path": 'priv/history/nick/' + nick
                     },
                     // success callback
                     sc = function (st) {
@@ -63,25 +67,42 @@ define ([
                             var history = st.payload.history.map(
                                 function (row) {
                                     return {
+                                        "nick": nick,
                                         "phid": row.phid,
                                         "priv": row.priv,
                                         "effective": lib.readableDate(row.effective)
                                     };
                                 }
                             );
-                            lib.holdObject(history);
-                            target.pull(tgt).start();
+                            if (tgt === 'privHistoryDtable') {
+                                stack.push(tgt, history, {
+                                    "xtarget": "mainPriv"
+                                });
+                            } else if (tgt === 'privHistoryDrowselect') {
+                                stack.push(tgt, {
+                                    'pos': 0,
+                                    'set': history
+                                });
+                            }
                         }
                     },
                     fc = function (st) {
                         console.log("AJAX: " + rest["path"] + " failed with", st);
-                        lib.displayError(st.payload.message);
                         if (st.payload.code === "404") {
                             // The employee has no history records. This is not
                             // really an error condition.
-                            lib.holdObject([]);
-                            target.pull(tgt).start();
+                            if (tgt === 'privHistoryDtable') {
+                                stack.push(tgt, [], {
+                                    "xtarget": "mainPriv"
+                                });
+                            } else if (tgt === 'privHistoryDrowselect') {
+                                stack.push(tgt, {
+                                    'pos': 0,
+                                    'set': []
+                                });
+                            }
                         }
+                        lib.displayError(st.payload.message);
                     };
                 ajax(rest, sc, fc);
             };
@@ -94,7 +115,8 @@ define ([
         "actionPrivHistoryEdit": genPrivHistoryAction(
                                      'privHistoryDrowselect'
                                  ),
-        "privHistorySaveAction": function () {
+        "privHistorySaveAction": function (obj) {
+            console.log("Entering privHistorySaveAction with obj", obj);
             var rest = {
                     "method": 'POST',
                     "path": 'priv/history/nick/' + currentUser('obj').nick,
@@ -107,7 +129,8 @@ define ([
                 sc = function (st) {
                     if (st.code === 'DOCHAZKA_CUD_OK') {
                         console.log("Payload is", st.payload);
-                        target.pull("actionPrivHistoryEdit").start();
+                        stack.unwindToTarget("actionPrivHistory");
+                        lib.displayError("Priv (status) history record successfully added");
                     }
                 },
                 fc = function (st) {
@@ -115,7 +138,7 @@ define ([
                     lib.displayError(st.payload.message);
                 };
             ajax(rest, sc, fc);
-            start.drowselectListen();
+            // start.drowselectListen();
         },
         "privHistoryDeleteAction": function () {
             var phid,
@@ -129,7 +152,8 @@ define ([
                 sc = function (st) {
                     if (st.code === 'DOCHAZKA_CUD_OK') {
                         console.log("Payload is", st.payload);
-                        target.pull("actionPrivHistoryEdit").start();
+                        stack.unwindToTarget("actionPrivHistory");
+                        lib.displayError("Priv (status) history record successfully deleted");
                     }
                 },
                 fc = function (st) {
@@ -145,7 +169,13 @@ define ([
             console.log("Going to delete PHID " + phid);
             rest.path += phid;
             ajax(rest, sc, fc);
-            start.drowselectListen();
+            // start.drowselectListen();
+        },
+        "privHistoryAddRecordAction": function (obj) {
+            console.log("Entering privHistoryAddRecordAction with obj", obj);
+            stack.push('privHistoryAddRecord', {
+                'nick': obj.nick
+            });
         }
     };
 
