@@ -47,7 +47,7 @@ define(['lib'], function (lib) {
             priv: null,
             effective: null,
             sanitize: function () {
-                // object might contain properties that don't belong - 
+                // object might contain properties that don't belong -
                 // this method removes them
                 var sanitized = lib.hairCut(this, [
                     'eid', 'nick', 'fullname', 'email', 'password', 'remark',
@@ -66,7 +66,7 @@ define(['lib'], function (lib) {
             remark: null,
             sec_id: null,
             sanitize: function () {
-                // object might contain properties that don't belong - 
+                // object might contain properties that don't belong -
                 // this method removes them
                 var sanitized = lib.hairCut(this, [
                     'eid', 'nick', 'fullname', 'email', 'password', 'remark',
@@ -86,7 +86,7 @@ define(['lib'], function (lib) {
             sec_id: null,
             dochazka: null,
             sanitize: function () {
-                // object might contain properties that don't belong - 
+                // object might contain properties that don't belong -
                 // this method removes them
                 var sanitized = lib.hairCut(this, [
                     'eid', 'nick', 'fullname', 'email', 'password', 'remark',
@@ -95,6 +95,43 @@ define(['lib'], function (lib) {
                 console.log("Sanitized empObject", sanitized);
                 return sanitized;
             }
+        },
+        schedObjectForCreate: {
+            scode: null,
+            schedule: null,
+            sanitize: function () {
+                // object might contain properties that don't belong -
+                // this method removes them
+                var sanitized = lib.hairCut(this, [
+                    'scode', 'schedule'
+                ]);
+                console.log("Sanitized schedObject", sanitized);
+                return sanitized;
+            }
+        },
+        schedObjectForDisplay: {
+            sid: null,
+            scode: null,
+            schedule: null,
+            disabled: null,
+            remark: null,
+            mon: null,
+            tue: null,
+            wed: null,
+            thu: null,
+            fri: null,
+            sat: null,
+            sun: null,
+            sanitize: function () {
+                // object might contain properties that don't belong -
+                // this method removes them
+                var sanitized = lib.hairCut(this, [
+                    'sid', 'scode', 'schedule', 'disabled', 'remark',
+                    'mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun'
+                ]);
+                console.log("Sanitized schedObject", sanitized);
+                return sanitized;
+            }
         }
     };
 });
